split\_dataset package
======================

Submodules
----------

split\_dataset.blocks module
----------------------------

.. automodule:: split_dataset.blocks
   :members:
   :undoc-members:
   :show-inheritance:

split\_dataset.split\_dataset module
------------------------------------

.. automodule:: split_dataset.split_dataset
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: split_dataset
   :members:
   :undoc-members:
   :show-inheritance:
